@@ -2,10 +2,11 @@
 
 from __future__ import annotations
 
+import locale
 import os
 from contextlib import redirect_stderr
 from pathlib import Path
-from typing import TYPE_CHECKING, Callable, NamedTuple, Sequence, cast
+from typing import TYPE_CHECKING, NamedTuple, cast
 
 from tox.config.source import Source, discover_source
 from tox.report import ToxHandler, setup_report
@@ -13,6 +14,8 @@ from tox.report import ToxHandler, setup_report
 from .parser import Parsed, ToxParser
 
 if TYPE_CHECKING:
+    from collections.abc import Callable, Sequence
+
     from tox.session.state import State
 
 
@@ -46,7 +49,10 @@ def _get_base(args: Sequence[str]) -> tuple[int, ToxHandler, Source]:
     tox_parser = ToxParser.base()
     parsed = Parsed()
     try:
-        with Path(os.devnull).open("w") as file_handler, redirect_stderr(file_handler):
+        with (
+            Path(os.devnull).open("w", encoding=locale.getpreferredencoding(do_setlocale=False)) as file_handler,
+            redirect_stderr(file_handler),
+        ):
             tox_parser.parse_known_args(args, namespace=parsed)
     except SystemExit:
         ...  # ignore parse errors, such as -va raises ignored explicit argument 'a'
@@ -64,7 +70,13 @@ def _get_base(args: Sequence[str]) -> tuple[int, ToxHandler, Source]:
 def _get_all(args: Sequence[str]) -> tuple[Parsed, dict[str, Callable[[State], int]]]:
     """Parse all the options."""
     tox_parser = _get_parser()
-    parsed = cast(Parsed, tox_parser.parse_args(args))
+    try:
+        import argcomplete  # noqa: PLC0415
+
+        argcomplete.autocomplete(tox_parser)
+    except ImportError:
+        pass
+    parsed = cast("Parsed", tox_parser.parse_args(args))
     handlers = {k: p for k, (_, p) in tox_parser.handlers.items()}
     return parsed, handlers
 
@@ -85,7 +97,10 @@ def _get_parser_doc() -> ToxParser:
 
     MANAGER.load_plugins(Path.cwd())
 
-    return _get_parser()  # pragma: no cover
+    parser = _get_parser()  # pragma: no cover
+    # Remove epilog message from help when formatting website docs
+    parser.epilog = None
+    return parser
 
 
 __all__ = (
