@@ -1,23 +1,34 @@
 from __future__ import annotations
 
 from collections import OrderedDict
-from typing import Iterator, Sequence
+from typing import TYPE_CHECKING
 
 from tox.execute.request import shell_cmd
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator, Sequence
+
 
 class CircularChainError(ValueError):
     """circular chain in config"""
 
 
+class MissingRequiredConfigKeyError(ValueError):
+    """missing required config key
+
+    Used by the two toml loaders in order to identify if config keys are present.
+
+    """
+
+
 class Command:  # noqa: PLW1641
     """A command to execute."""
 
     def __init__(self, args: list[str]) -> None:
-        """
-        Create a new command to execute.
+        """Create a new command to execute.
 
         :param args: the command line arguments (first value can be ``-`` to indicate ignore the exit code)
+
         """
         self.ignore_exit_code: bool = args[0] == "-"  #: a flag indicating if the exit code should be ignored
         self.invert_exit_code: bool = args[0] == "!"  #: a flag for flipped exit code (non-zero = success, 0 = error)
@@ -30,10 +41,12 @@ class Command:  # noqa: PLW1641
         return f"{type(self).__name__}(args={args!r})"
 
     def __eq__(self, other: object) -> bool:
-        return type(self) == type(other) and (self.args, self.ignore_exit_code, self.invert_exit_code) == (  # noqa: E721
-            other.args,  # type: ignore[attr-defined]
-            other.ignore_exit_code,  # type: ignore[attr-defined]
-            other.invert_exit_code,  # type: ignore[attr-defined]
+        if not isinstance(other, Command):
+            return False
+        return (self.args, self.ignore_exit_code, self.invert_exit_code) == (
+            other.args,
+            other.ignore_exit_code,
+            other.invert_exit_code,
         )
 
     def __ne__(self, other: object) -> bool:
@@ -41,7 +54,7 @@ class Command:  # noqa: PLW1641
 
     @property
     def shell(self) -> str:
-        """:return: a shell representation of the command (platform dependent)"""
+        """:returns: a shell representation of the command (platform dependent)"""
         return shell_cmd(self.args)
 
 
@@ -49,10 +62,10 @@ class EnvList:  # noqa: PLW1641
     """A tox environment list."""
 
     def __init__(self, envs: Sequence[str]) -> None:
-        """
-        Crate a new tox environment list.
+        """Crate a new tox environment list.
 
         :param envs: the list of tox environments
+
         """
         self.envs = list(OrderedDict((e, None) for e in envs).keys())
 
@@ -60,13 +73,15 @@ class EnvList:  # noqa: PLW1641
         return f"{type(self).__name__}({self.envs!r})"
 
     def __eq__(self, other: object) -> bool:
-        return type(self) == type(other) and self.envs == other.envs  # type: ignore[attr-defined]  # noqa: E721
+        if not isinstance(other, EnvList):
+            return False
+        return self.envs == other.envs
 
     def __ne__(self, other: object) -> bool:
         return not (self == other)
 
     def __iter__(self) -> Iterator[str]:
-        """:return: iterator that goes through the defined env-list"""
+        """:returns: iterator that goes through the defined env-list"""
         return iter(self.envs)
 
 
