@@ -1,10 +1,11 @@
 """A executor that reuses a single subprocess for all backend calls (saving on python startup/import overhead)."""
+
 from __future__ import annotations
 
 import time
 from subprocess import TimeoutExpired
 from threading import Lock
-from typing import TYPE_CHECKING, Sequence
+from typing import TYPE_CHECKING
 
 from pyproject_api import BackendFailed
 
@@ -15,6 +16,7 @@ from tox.execute.request import StdinSource
 from tox.execute.stream import SyncWrite
 
 if TYPE_CHECKING:
+    from collections.abc import Sequence
     from pathlib import Path
     from types import TracebackType
 
@@ -53,14 +55,14 @@ class LocalSubProcessPep517Executor(Execute):
                 err=SyncWrite(name="pep517-err", target=None, color=None),  # not enabled no need to enter/exit
                 on_exit_drain=False,
             )
-            status = instance.__enter__()
+            status = instance.__enter__()  # noqa: PLC2801
             self._local_execute = instance, status
             while True:
                 if b"started backend " in status.out:
                     self.is_alive = True
                     break
                 if b"failed to start backend" in status.err:
-                    from tox.tox_env.python.virtual_env.package.pyproject import ToxBackendFailed
+                    from tox.tox_env.python.virtual_env.package.pyproject import ToxBackendFailed  # noqa: PLC0415
 
                     failure = BackendFailed(
                         result={
@@ -83,20 +85,21 @@ class LocalSubProcessPep517Executor(Execute):
 
     def close(self) -> None:
         if self._local_execute is not None:  # pragma: no branch
-            execute, status = self._local_execute
-            execute.__exit__(None, None, None)
+            execute, _status = self._local_execute
             if execute.process is not None and execute.process.returncode is None:  # pragma: no cover
                 try:  # pragma: no cover
                     execute.process.wait(timeout=0.1)  # pragma: no cover
                 except TimeoutExpired:  # pragma: no cover
                     execute.process.terminate()  # pragma: no cover  # if does not stop on its own kill it
+            execute.__exit__(None, None, None)
+            self._local_execute = None
         self.is_alive = False
 
 
 class LocalSubProcessPep517ExecuteInstance(ExecuteInstance):
     """A backend invocation."""
 
-    def __init__(  # noqa: PLR0913
+    def __init__(
         self,
         request: ExecuteRequest,
         options: ExecuteOptions,
