@@ -1,7 +1,4 @@
-"""
-Please keep this file Python 2.7 compatible.
-See https://tox.readthedocs.io/en/rewrite/development.html#code-style-guide
-"""
+"""Please keep this file Python 2.7 compatible. See https://tox.readthedocs.io/en/rewrite/development.html#code-style-guide"""
 
 from __future__ import annotations
 
