@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import os
 import platform
 import sys
 from configparser import ConfigParser
@@ -100,7 +101,7 @@ def test_show_config_exception(tox_project: ToxProjectCreator) -> None:
     outcome.assert_failed(code=-1)
     txt = (
         "\nenv_site_packages_dir = # Exception: "
-        "RuntimeError(\"failed to find interpreter for Builtin discover of python_spec='missing-python'"
+        "Skip(\"failed to find interpreter for Builtin discover of python_spec='missing-python'"
     )
     assert txt in outcome.out
 
@@ -354,6 +355,42 @@ def test_package_env_inherits_from_pkgenv(tox_project: ToxProjectCreator, demo_p
     assert exp in outcome.out
 
 
+def test_cross_section_envpython_resolves_to_calling_env(tox_project: ToxProjectCreator) -> None:
+    project = tox_project({
+        "tox.ini": dedent("""\
+            [testenv:a]
+            package = skip
+            commands = {envpython} -m black .
+
+            [testenv:b]
+            package = skip
+            commands = {[testenv:a]commands}
+        """),
+    })
+    outcome = project.run("c", "-e", "a,b", "-k", "commands")
+    outcome.assert_success()
+    lines = outcome.out.splitlines()
+    a_cmd = next(line for line in lines if line.startswith("commands") and lines.index(line) < lines.index(""))
+    b_cmd = [line for line in lines if line.startswith("commands")][-1]
+    sep = os.sep
+    assert f".tox{sep}a{sep}" in a_cmd
+    assert f".tox{sep}b{sep}" in b_cmd
+    assert f".tox{sep}a{sep}" not in b_cmd
+
+
+def test_factor_conditional_falls_back_to_default(tox_project: ToxProjectCreator) -> None:
+    py_ver = f"{sys.version_info[0]}.{sys.version_info[1]}"
+    ini = (
+        f"[tox]\nenv_list=py{py_ver}-a,py{py_ver}-b\nno_package=true\n[testenv]\nbase_python =\n    a: python{py_ver}\n"
+    )
+    outcome = tox_project({"tox.ini": ini}).run("c", "-e", f"py{py_ver}-a,py{py_ver}-b", "-k", "base_python")
+    outcome.assert_success()
+    parser = ConfigParser(interpolation=None)
+    parser.read_string(outcome.out)
+    assert parser.get(f"testenv:py{py_ver}-a", "base_python") == f"python{py_ver}"
+    assert parser.get(f"testenv:py{py_ver}-b", "base_python") == f"py{py_ver}"
+
+
 def test_core_on_platform(tox_project: ToxProjectCreator) -> None:
     project = tox_project({"tox.ini": "[tox]\nno_package = true"})
     result = project.run("c", "-e", "py", "--core", "-k", "on_platform")
