@@ -32,6 +32,14 @@ CURRENT_PY_ENV = f"py{sys.version_info[0]}{sys.version_info[1]}"  # e.g. py310
         (",,", (), False, True),
         #   Environment names with "invalid" characters are accepted here; the client is expected to deal with this.
         ("\x01.-@\x02,xxx", ("\x01.-@\x02", "xxx"), False, False),
+        #   Brace expansion produces the cartesian product of factors.
+        (
+            "py{38,39}-pytest{6.x,7.x}",
+            ("py38-pytest6.x", "py38-pytest7.x", "py39-pytest6.x", "py39-pytest7.x"),
+            False,
+            False,
+        ),
+        ("a{1,2},b", ("a1", "a2", "b"), False, False),
     ],
 )
 def test_clienv(user_input: str, env_names: tuple[str], is_all: bool, is_default: bool) -> None:
@@ -54,6 +62,24 @@ def test_clienv_is_all(user_input: str, expected: bool) -> None:
     assert CliEnv(user_input).is_all is expected
 
 
+def test_clienv_iadd() -> None:
+    cli_env = CliEnv("a,b")
+    cli_env += CliEnv("c,d")
+    assert list(cli_env) == ["a", "b", "c", "d"]
+
+
+def test_clienv_iadd_from_default() -> None:
+    cli_env = CliEnv()
+    cli_env += CliEnv("c")
+    assert list(cli_env) == ["c"]
+
+
+def test_clienv_iadd_noop() -> None:
+    cli_env = CliEnv("a")
+    cli_env += CliEnv()
+    assert list(cli_env) == ["a"]
+
+
 def test_env_select_lazily_looks_at_envs() -> None:
     state = State(get_options(), [])
     env_selector = EnvSelector(state)
@@ -213,6 +239,15 @@ def test_tox_skip_env_logs(tox_project: ToxProjectCreator, monkeypatch: MonkeyPa
     outcome.assert_out_err("ROOT: skip environment mypy, matches filter 'm[y]py'\npy310\npy39\n", "")
 
 
+def test_multiple_e_flags_are_additive(tox_project: ToxProjectCreator) -> None:
+    proj = tox_project({"tox.ini": "[tox]\nenv_list=a,b,c"})
+    outcome = proj.run("c", "-e", "a", "-e", "b", "-k", "env_name")
+    outcome.assert_success()
+    assert "[testenv:a]" in outcome.out
+    assert "[testenv:b]" in outcome.out
+    assert "[testenv:c]" not in outcome.out
+
+
 def test_cli_env_can_be_specified_in_default(tox_project: ToxProjectCreator) -> None:
     proj = tox_project({"tox.ini": "[tox]\nenv_list=exists"})
     outcome = proj.run("r", "-e", "exists")
@@ -324,6 +359,15 @@ def test_dynamic_env_factors_not_match(env: str) -> None:
     assert not _DYNAMIC_ENV_FACTORS.fullmatch(env)
 
 
+@pytest.mark.parametrize("env_name", ["functional-py312", "functional"])
+def test_partial_section_match_rejected(env_name: str, tox_project: ToxProjectCreator) -> None:
+    tox_ini = "[testenv]\nskip_install = true\ncommands=python -c 'print(1)'\n[testenv:functional{-py310}]\n"
+    proj = tox_project({"tox.ini": tox_ini})
+    outcome = proj.run("r", "-e", env_name)
+    outcome.assert_failed(code=-2)
+    assert "provided environments not found in configuration file" in outcome.out
+
+
 def test_suggest_env(tox_project: ToxProjectCreator) -> None:
     tox_ini = f"[testenv:release]\n[testenv:py3{_MINOR}]\n[testenv:alpha-py3{_MINOR}]\n"
     proj = tox_project({"tox.ini": tox_ini})
